@@ -33,6 +33,28 @@ namespace Beagle.Util {
 
 	public class Scheduler {
 
+		static private bool no_delays = false;
+		static private bool immediate_priority_only = false;
+
+		static Scheduler ()
+		{
+			if (Environment.GetEnvironmentVariable ("EXERCISE_THE_DOG") != null) {
+				Logger.Log.Warn ("***");
+				Logger.Log.Warn ("*** The EXERCISE_THE_DOG environment variable is deprecated.");
+				Logger.Log.Warn ("*** Please use BEAGLE_EXERCISE_THE_DOG in the future.");
+				Logger.Log.Warn ("*** We will now proceed to exercise the dog.  Thank you.");
+				Logger.Log.Warn ("***");
+				no_delays = true;
+			} else if (Environment.GetEnvironmentVariable ("BEAGLE_EXERCISE_THE_DOG") != null) {
+				no_delays = true;
+			}
+	
+			if (Environment.GetEnvironmentVariable ("BEAGLE_IMMEDIATE_PRIORITY_ONLY") != null)
+				immediate_priority_only = true;
+		}
+
+		//////////////////////////////////////////////////////////////////////////////
+
 		static private Scheduler global = new Scheduler ();
 
 		static public Scheduler Global {
@@ -394,6 +416,10 @@ namespace Beagle.Util {
 
 			lock (task_queue) {
 				if (task != null) {
+					
+					if (immediate_priority_only && task.Priority != Priority.Immediate)
+						return false;
+
 					old_task = task_by_tag [task.Tag] as Task;
 					if (old_task == task)
 						return true;
@@ -543,6 +569,9 @@ namespace Beagle.Util {
 		private double ComputeDelay (Priority priority_of_next_task,
 					     double   duration_of_previous_task)
 		{
+			if (no_delays)
+				return 0;
+
 			double rate_factor;
 
 			rate_factor = 2.0;
