@@ -230,22 +230,21 @@ namespace Beagle.Daemon {
 
 			string path = ContentUri.LocalPath;
 
-#if false
-			flavor = Flavor.FromMimeType (MimeType);
-			filter = Filter.FromFlavor (flavor);
-#endif
 			filter = FilterFactory.CreateFilterFromMimeType (MimeType);
 			
-
 			if (filter != null) {
 
-#if false // For now we explicitly ignore SnippetMode
-				if (filter.SnippetMode) {
-					TextWriter writer = TextCache.GetWriter (Uri);
-					filter.AttachSnippetWriter (writer);
-				}
-#endif
+				filter.Identifier = ContentUri.LocalPath;
 
+				if (filter.SnippetMode) {
+					if (filter.OriginalIsText) {
+						TextCache.MarkAsSelfCached (Uri);
+					} else {
+						TextWriter writer = TextCache.GetWriter (Uri);
+						filter.AttachSnippetWriter (writer);
+					}
+				}
+				
 				if (crawl_mode)
 					filter.EnableCrawlMode ();
 				filter.Open (new FileInfo (path));
@@ -268,19 +267,10 @@ namespace Beagle.Daemon {
 			get { return filter != null; }
 		}
 
-#if false
-		public Flavor Flavor {
-			get { return flavor; }
-		}
-#endif
-
 		public FileInfo GetFileInfo () {
-			if (Uri.ToString().StartsWith ("file://")) {
-				string path = Uri.ToString().Substring ("file://".Length);
-				return new FileInfo (path);
-			} else {
-				return null;
-			}
+			if (Uri.IsFile) 
+				return new FileInfo (Uri.LocalPath);
+			return null;
 		}
 	}
 
